"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rule_1 = require("../rule");
class Deprecated extends rule_1.Rule {
    documentation() {
        return {
            description: "HTML5 deprecated many old elements and they should not be used in new code.",
            url: rule_1.ruleDocumentationUrl(__filename),
        };
    }
    setup() {
        this.on("tag:open", (event) => {
            const node = event.target;
            if (node.meta === null) {
                return;
            }
            const deprecated = node.meta.deprecated;
            if (deprecated) {
                if (typeof deprecated === "string") {
                    this.report(node, `<${node.tagName}> is deprecated: ${deprecated}`);
                }
                else {
                    this.report(node, `<${node.tagName}> is deprecated`);
                }
            }
        });
    }
}
module.exports = Deprecated;
